@@ -135,8 +135,7 @@ ctPredictTIP <- function(sf,tipreds='all',subject=1,timestep='auto',doDynamics=T
 #' 
 #' @param fit fit object as generated by \code{\link{ctStanFit}}.
 #' @param timerange Either 'asdata' to just use the observed data range, or a numeric vector of length 2 denoting start and end of time range, 
-#' allowing for estimates outside the range of observed data. Ranges smaller than the observed data
-#' are ignored.
+#' allowing for estimates outside the range of observed data. Ranges smaller than the observed data are ignored.
 #' @param timestep Either 'asdata' to just use the observed data 
 #' (which also requires 'asdata' for timerange) or a positive numeric value
 #' indicating the time step to use for interpolating values. Lower values give a more accurate / smooth representation,
@@ -212,7 +211,7 @@ ctKalman<-function(fit, timerange='asdata', timestep='auto',
   subjects <- sort(subjects) #in case not entered in ascending order
   
   out <- ctStanKalman(fit,pointest=TRUE, 
-    removeObs=removeObs, subjects=subjects,timestep = timestep,
+    removeObs=removeObs, subjects=subjects,timestep = timestep,maxtime=max(timerange),
     collapsefunc=mean, indvarstates = FALSE,standardisederrors = standardisederrors) #extract state predictions
   
   out <- meltkalman(out)
@@ -349,7 +348,8 @@ plot.ctKalmanDF<-function(x, subjects=unique(x$Subject), kalmanvec=c('y','yprior
     geom_line()+
     geom_point()+
     theme_minimal()+
-    guides(fill='none')
+    guides(fill='none')+
+    theme(legend.position = 'bottom')
   
   return(g)
   
