@@ -28,13 +28,14 @@ ctModelUnlist<-function(ctmodelobj,
 #' Convert a frequentist (omx) ctsem model specification to Bayesian (Stan).
 #'
 #' @param ctmodelobj ctsem model object of type 'omx' (default)
-#' @param type either 'stanct' for continuous time, or 'standt' for discrete time.
+#' @param type either 'ct' for continuous time, or 'dt' for discrete time.
 #' @param tipredDefault Logical. TRUE sets any parameters with unspecified time independent 
 #' predictor effects to have effects estimated, FALSE fixes the effect to zero unless individually specified.
 #'
 #' @return List object of class ctStanModel, with random effects specified for any intercept type parameters
 #' (T0MEANS, MANIFESTMEANS, and or CINT), and time independent predictor effects for all parameters. Adjust these
 #' after initial specification by directly editing the \code{pars} subobject, so \code{model$pars} . 
+#' @importFrom rstantools rstan_config
 #' @export
 #'
 #' @examples
@@ -54,9 +55,17 @@ ctModelUnlist<-function(ctmodelobj,
 #' stanmodel=ctStanModel(model)
 #' 
 #' 
-ctStanModel<-function(ctmodelobj, type='stanct',tipredDefault=TRUE){
-  if(type=='stanct') continuoustime<-TRUE
-  if(type=='standt') continuoustime<-FALSE
+ctStanModel<-function(ctmodelobj, type='ct',tipredDefault=TRUE){
+  if(FALSE) rstanconfig() #placeholder to use rstantools
+  if(type=='stanct' | type=='standt'){
+    warning('type should now be specified as simply ct or dt, without the stan prefix')
+    type <- gsub('stan','',type)
+  }
+  
+  if(type=='ct') continuoustime<-TRUE
+  if(type=='dt') continuoustime<-FALSE
+  
+  if(!type %in% c('ct','dt')) stop('type must be either ct or dt!')
   
   ctm <- ctmodelobj
   
@@ -241,7 +250,7 @@ ctStanModel<-function(ctmodelobj, type='stanct',tipredDefault=TRUE){
   
   for(ri in 1:nrow(ctspec)){ #set NA's on complex params
     
-    if(grepl('\\W',gsub('.','',ctspec$param[ri],fixed=TRUE)) || ctspec$param[ri] %in% latentNames){
+    if(grepl('\\W',gsub('.','',ctspec$param[ri],fixed=TRUE)) || ctspec$param[ri] %in% latentNames){ #if non word chars or state ref
       ctspec$value[ri] <- NA
       if(!simpleStateCheck(ctspec$param[ri])) ctspec$transform[ri] <-NA #allow transforms for simplestates
       if(simpleStateCheck(ctspec$param[ri])) ctspec$transform[ri] <-'param' #allow transforms for simplestates
@@ -256,7 +265,8 @@ ctStanModel<-function(ctmodelobj, type='stanct',tipredDefault=TRUE){
     TIpredNames=TIpredNames,TDpredNames=TDpredNames,
     subjectIDname=ctm$id,
     timeName=ctm$time,
-    continuoustime=continuoustime)
+    continuoustime=continuoustime,
+    manifesttype=ctmodelobj$manifesttype)
   class(out)<-'ctStanModel'
   
   out$tipredeffectscale <- 1
@@ -268,7 +278,6 @@ ctStanModel<-function(ctmodelobj, type='stanct',tipredDefault=TRUE){
   out$rawpopsdtransform <- 'log1p_exp(2*rawpopsdbase-1) .* sdscale' #'log(1+exp(2*rawpopsdbase)) .* sdscale' #'exp(rawpopsdbase * 2 -2) .* sdscale' # 'rawpopsdbase .* sdscale' #
   # out$stationarymeanprior <- NA
   # out$stationaryvarprior <- NA
-  out$manifesttype <- rep(0,n.manifest)
   out$covmattransform <- 'rawcorr'
   # out$NOrdinalIntegrationPoints <- 9L
   
