@@ -7,7 +7,7 @@ ctsmupdate<-function(usecurrentwd=FALSE,scat=FALSE){
   datalong <- cbind(id, time, sunspots)
   
   #setup model
-  model <- ctModel(type='stanct', n.latent=2, n.manifest=1, 
+  model <- ctModel(type='ct', n.latent=2, n.manifest=1, 
     manifestNames='sunspots', 
     latentNames=c('ss_level', 'ss_velocity'),
     LAMBDA=matrix(c( 1, 'ma1' ), nrow=1, ncol=2),
